package org.norberg.XmlTvToVdr;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * (c) 2003 Stefan Norberg (stefan@norberg.org)
 */
public class EpgEvent {
	
	private int eventId;
	private String title;
	private String shortDescription;;
	private String description;
	private Date startTime;
	private Date endTime;
	
	private SimpleDateFormat xmlDateFormat;

	public EpgEvent() {
	}
	
	public EpgEvent(String title, String description, String startTime, String endTime) {
		eventId = Util.getCurrentEventId();
		this.title = title;
		this.description = description;
		xmlDateFormat = new SimpleDateFormat("yyyyMMddHHmmss Z");
		try {
			this.startTime = xmlDateFormat.parse(startTime);
			this.endTime = xmlDateFormat.parse(endTime);
		} catch (ParseException e) {
			e.printStackTrace();
		}
	}
	
	public String vdrFormat() {
		StringBuffer sb = new StringBuffer();
		sb.append("E " + eventId + " " +
		    startTime.getTime()/1000 + " " +
		    (endTime.getTime() - startTime.getTime())/1000 + "\n");
		sb.append("T " + (title != null ? title : "") + "\n");
		sb.append("S " + (shortDescription != null ? shortDescription : "") + "\n");
		sb.append("D " + (description != null ? description : "") + "\n");
		sb.append("e\n");
		
		return sb.toString();
	}

	public String toString() {
		StringBuffer sb = new StringBuffer();
		sb.append("Title: " + title + "\n");
		sb.append("Descr: " + description + "\n");
		sb.append("start: " + startTime + "\n");
		sb.append("end: "   + endTime + "\n");
		
		return sb.toString();
	}
	/**
	 * Returns the description.
	 * @return String
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * Returns the endTime.
	 * @return Date
	 */
	public Date getEndTime() {
		return endTime;
	}

	/**
	 * Returns the eventId.
	 * @return int
	 */
	public int getEventId() {
		return eventId;
	}

	/**
	 * Returns the shortDescription.
	 * @return String
	 */
	public String getShortDescription() {
		return shortDescription;
	}

	/**
	 * Returns the startTime.
	 * @return Date
	 */
	public Date getStartTime() {
		return startTime;
	}

	/**
	 * Returns the title.
	 * @return String
	 */
	public String getTitle() {
		return title;
	}

	/**
	 * Sets the description.
	 * @param description The description to set
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Sets the endTime.
	 * @param endTime The endTime to set
	 */
	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}

	/**
	 * Sets the eventId.
	 * @param eventId The eventId to set
	 */
	public void setEventId(int eventId) {
		this.eventId = eventId;
	}

	/**
	 * Sets the shortDescription.
	 * @param shortDescription The shortDescription to set
	 */
	public void setShortDescription(String shortDescription) {
		this.shortDescription = shortDescription;
	}

	/**
	 * Sets the startTime.
	 * @param startTime The startTime to set
	 */
	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}

	/**
	 * Sets the title.
	 * @param title The title to set
	 */
	public void setTitle(String title) {
		this.title = title;
	}

}
