package org.norberg.XmlTvToVdr;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;

/**
 * (c) 2003 Stefan Norberg (stefan@norberg.org)
 */
public class PropertiesManager {
	
	private static PropertiesManager instance;
	private Properties props;

	private PropertiesManager() {
		props = new Properties();
		try {
			props.load(new FileInputStream("xmltvtovdr.properties"));
		} catch (FileNotFoundException e) {
			System.out.println(e.getMessage());
		} catch (IOException e) {
			System.out.println(e.getMessage());
		}
	}
	
	public static PropertiesManager getInstance() {
		if (instance == null) {
			instance = new PropertiesManager();
		}
		return instance;
	}		

	public String getChannelName(String xmlName) {
		String name = props.getProperty(xmlName + ".name");
		if (name == null) {
			System.err.println("Unknown VdrServiceId for " + xmlName);
			System.exit(1);
		}
		return name;

	}
	
	public String getServiceId(String xmlName) {
		String sId = props.getProperty(xmlName + ".serviceId");
		if (sId == null) {
			System.err.println("Unknown VdrServiceId for " + xmlName);
			System.exit(1);
		}
		return sId;
	}

	public String getVdrHostname() {
		String hostname = props.getProperty("vdr.svdrp.host");
		if (hostname == null) {
			System.err.println("Error: no vdr host found in properties");
			System.err.println("add \"vdr.svdrp.host=my.vdr.box.com\" to the properties file");
			System.exit(1);
		}
		return hostname;
	}
	
	public int getSvdrpPort() {
		String port = props.getProperty("vdr.svdrp.port");
		if (port == null) {
			System.err.println("Error: no SVDRP port in properties");
			System.err.println("add \"vdr.svdrp.port=2001\" to the properties file");
			System.exit(1);
		}
		return new Integer(port).intValue();
	}

	public String getXmlFileName() {
		String filename = props.getProperty("xmltv.file");
		if (filename == null) {
			System.err.println("Error: no XMLTV file in properties");
			System.err.println("add \"xmltv.file=tv.xml\" to the properties file");
			System.exit(1);
		}
		return filename;
	}
}
